/* 
Copyright 2011, Matthew Roberts
This work is licensed under a Creative Commons Attribution 3.0 Unported License.
http://creativecommons.org/licenses/by/3.0/
*/ 

a = 60;			// angle,								60 on a mendel
d = 8;			// rod diameter,							8mm on a mendel
d2 = 3;			// small rod diameter,						3mm on a mendel
s = 58;			// spacing of two large vertical holes,				58mm on a mendel
s2 = d*1.5;			// spacing of vertical hole to nearest horizontal hole,	12mm on a mendel
s3 = 20;			// spacing of two small vertical  holes,			20mm on a mendel
t = 5;				// wall thickness							5mm on a mendel
h = d+2*t;			// height								20mm on a mendel
w = h;			// width								30mm on a mendel
foot_d_shaft = 4;		// diameter of adjustable foot bolt hole,			not on a mendel
foot_d_hex = 7;		// diameter of adjustable foot captive nut,			not on a mendel
foot_l_hex = 6;		// height of adjustable foot captive nut,			not on a mendel
foot_l = foot_l_hex+t;	// length of foot,							not on a mendel

foot_D_hex = foot_d_hex * 2 / sqrt(3);
$fn = 80;
inf = 1000;
eps = 0.0001;

module end(round = false, foot=false, teardrop=true) {
	difference() {
		union() {
			translate([0,(t+d+s2+t)/2-(t+d/2),0])
				cube([w,t+d+s2+t,h], center=true);
			
			if (foot) {
				translate([0,-foot_l/2-d/2-t/2,0]) cube([min(w,h),foot_l+t,h+eps], center=true);
			}
		}

		cylinder(r=d/2, h=100, center=true);
		translate([0,s2,0]) rotate([0, -90, 0])
			union() {
				cylinder(r=d/2, h=inf, center=true);
				if (teardrop)
					translate([d/2*sin(45),0,0]) rotate([0,0,45]) cube([d/2,d/2,inf], center=true);
			}

		scale([1, (d+2*t) / w, 1])
			difference() {
				translate([0,-w/2,0])
					cube([w+eps,w,100+eps], center=true);

				if (round)
					cylinder(r=w/2+eps, h=100, center=true);
				else
					cylinder(r=w/2+eps, h=100, center=true,$fn=6);
				if (foot)
					cube([min(w,h),inf,h+eps], center=true);
			}

		if (foot) {
			rotate([90,0,0]) translate([0,0,inf/2])cylinder(r=foot_d_shaft/2,h=inf, center=true);
			translate([0,-d/2-t-foot_l_hex/2,0]) {
				rotate([90,30,0]) cylinder(r=foot_D_hex/2,h=foot_l_hex,$fn=6, center=true);
				translate([0,0,inf/2]) cube([foot_d_hex,foot_l_hex,inf], center=true);
			}
		}
	}
}

module vertex(round=false, middle=true, foot=false, teardrop=true) {
	ex = -sin(a/2)*(s2+d/2+t);
	ey = (s/2 - cos(a/2)*(s2+d/2+t));
	cx = ex+tan(90-a/2)*ey;
	cy = 0;
	r = sqrt((ex-cx)*(ex-cx)+(ey-cy)*(ey-cy));

	translate([0,0,h/2]) difference() {
		union() {
			translate([0,-s/2,0]) rotate([0,0,a/2]) end(round=round, teardrop=teardrop);
			mirror([0,1,0]) translate([0,-s/2,0]) rotate([0,0,a/2]) end(round=round, foot=foot, teardrop=teardrop);

			intersection() {
				translate([cx,cy,0]) {
					difference() {
						cylinder(r=r+w/2,h=h+eps,center=true);
						cylinder(r=r-w/2,h=inf+eps,center=true);

						if (!middle) {
							difference() {
								cylinder(r=r+w/2-t,h=h+eps,center=true);
								cylinder(r=r-w/2+t,h=inf+eps,center=true);
							}
						}
					}
				}
				translate([0, -s/2, 0]) rotate([0,0,a/2])
					translate([inf/2-w/2,inf/2+s2+d/2+t-eps,0]) cube([inf,inf,inf], center=true);
				mirror([0,1,0]) translate([0, -s/2, 0]) rotate([0,0,a/2])
					translate([inf/2-w/2,inf/2+s2+d/2+t-eps,0]) cube([inf,inf,inf], center=true);
			}
		}

		if (middle) {
			translate([cx-r,cy,0]) {
				cylinder(r=d/2, h=inf+eps, center=true);
				translate([0,s3/2,0])
					cylinder(r=d2/2, h=inf+eps, center=true);
				translate([0,-s3/2,0])
					cylinder(r=d2/2, h=inf+eps, center=true);
			}
		}
	}
}

translate([-50,0,0])
	vertex(); // default
translate([0,0,0])
	vertex(round = true, middle=false, foot = false, teardrop=true); // top
translate([50,0,0])
	vertex(round = true, middle=false, foot = true, teardrop=true); // bottom
